// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';

abstract class ThemeImporter {
  /// Imports a [ThemeData] from either a [BuildContext] or a [ThemeData].
  ///
  /// Throws an [ArgumentError] if the type of [from] is not a [BuildContext]
  /// or a [ThemeData].
  static ThemeData importFrom<T>(T from) {
    ThemeData theme;

    if (from is BuildContext) {
      theme = Theme.of(from);
    } else if (from is ThemeData) {
      theme = from;
    } else {
      throw ArgumentError(
        'from must be either a BuildContext or a ThemeData',
      );
    }

    return theme;
  }
}
